Index: sdk/lib/_internal/pub/lib/src/executable.dart |
diff --git a/sdk/lib/_internal/pub/lib/src/executable.dart b/sdk/lib/_internal/pub/lib/src/executable.dart |
index 966b68f6d7f6efb6b980c407cc3d531ad787f646..1c22b801339ed241c6455c2a2d57672bd501253c 100644 |
--- a/sdk/lib/_internal/pub/lib/src/executable.dart |
+++ b/sdk/lib/_internal/pub/lib/src/executable.dart |
@@ -186,9 +186,9 @@ Future<int> runSnapshot(String path, Iterable<String> args, {recompile(), |
} |
var exitCode = await runProcess(stdin1); |
- if (recompile == null || exitCode != 255) return exitCode; |
+ if (recompile == null || exitCode != 253) return exitCode; |
- // Exit code 255 indicates that the snapshot version was out-of-date. If we |
+ // Exit code 253 indicates that the snapshot version was out-of-date. If we |
// can recompile, do so. |
await recompile(); |
return runProcess(stdin2); |